==> mosh-0.2.3.tar.gz: mosh-0.2.3/src/NumberReader.tab.hpp <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     END_OF_FILE = 258,
     PLUS = 259,
     MINUS = 260,
     SLASH = 261,
     DOT = 262,
     AT = 263,
     MY_NAN = 264,
     MY_INF = 265,
     IMAG = 266,
     RADIX_2 = 267,
     RADIX_8 = 268,
     RADIX_10 = 269,
     RADIX_16 = 270,
     EXACT = 271,
     INEXACT = 272,
     DIGIT_2 = 273,
     DIGIT_8 = 274,
     DIGIT_10 = 275,
     DIGIT_16 = 276,
     EXPONENT_MARKER = 277
   };
#endif



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED

# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

==> mosh-0.2.4.tar.gz: mosh-0.2.4/src/NumberReader.tab.hpp <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     END_OF_FILE = 258,
     PLUS = 259,
     MINUS = 260,
     SLASH = 261,
     DOT = 262,
     AT = 263,
     MY_NAN = 264,
     MY_INF = 265,
     IMAG = 266,
     RADIX_2 = 267,
     RADIX_8 = 268,
     RADIX_10 = 269,
     RADIX_16 = 270,
     EXACT = 271,
     INEXACT = 272,
     DIGIT_2 = 273,
     DIGIT_8 = 274,
     DIGIT_10 = 275,
     DIGIT_16 = 276,
     EXPONENT_MARKER = 277
   };
#endif
/* Tokens.  */
#define END_OF_FILE 258
#define PLUS 259
#define MINUS 260
#define SLASH 261
#define DOT 262
#define AT 263
#define MY_NAN 264
#define MY_INF 265
#define IMAG 266
#define RADIX_2 267
#define RADIX_8 268
#define RADIX_10 269
#define RADIX_16 270
#define EXACT 271
#define INEXACT 272
#define DIGIT_2 273
#define DIGIT_8 274
#define DIGIT_10 275
#define DIGIT_16 276
#define EXPONENT_MARKER 277




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif
